@@ -160,7 +160,7 @@ def ProcessAlarm():
     if(peak>(data.Trigger*data.Yscale_Sleep_Pattern*3/40)): #Trigger Alarm
        if(records.AlarmIsSet==True and data.AlarmIsActive==False): #alarm is set
             if(now>=records.AlarmTimeWindowStart_seconds and now<records.AlarmTimeWindowEnd_seconds): # we are in alarm time window
-                if(data.WakeUp_SongIsActive==False):#wake up song (if enabled) is not playing
+                if(data.WakeUp_SongIsActive==False):#wake up song (if enabled) is not yet playing
                     print "************ ALARM ALARM (Movement over trigger level)"
                     print "*", strftime("%x %X"), "ProcessAlarm => DeleteAlarm" #for log file
                     DeleteAlarm() #delete old alarm if existing
@@ -198,9 +198,16 @@ def ProcessAlarm():
 #            PauseSong() #stop playing song, in case it was playing
             CloseMediaPlayer() #close media player
 
+    elif(records.Use_WakeUp_Song==True and (now+records.WakeUp_Song_Duration>=records.AlarmTimeWindowEnd_seconds)): #almost at end of alarm time window, play wake up song
+        if(data.WakeUp_SongIsActive==False):#wake up song (if enabled) is not yet playing
+            data.WakeUp_SongIsActive=True
+            records.WakeUp_Song_Start_tuple=Seconds2Tuple(now)
+            print "** Play wake up song"
+            PlaySong(0, records.WakeUp_Song) #start quiet, get louder over time
+
     if(data.WakeUp_SongIsActive==True): #when WakeUp music is active, increase volume over time
 #        print records.WakeUp_Song_Volume,  data.CurrentVolume, data.CurrentVolume, float(data.WakeUp_Song_Volume_Increase_Step)/10, data.WakeUp_Song_Volume_Increase_Step
-        if(records.WakeUp_Song_Volume>data.CurrentVolume):
+        if(records.WakeUp_Song_Volume>=data.CurrentVolume):
             data.CurrentVolume=data.CurrentVolume+(float(data.WakeUp_Song_Volume_Increase_Step)/10) #increase the volume slowly
             SetVolume(data.CurrentVolume)
             print "Increase volume to:", data.CurrentVolume
