@@ -41,7 +41,7 @@ def CreateRecordFile():
     else: data.RecordFolder=data.defaultRecordFolder
 
     print "RecordFolder:", data.RecordFolder
-    if(not os.path.exists(data.RecordFolder)): #create record folder
+    if(not os.path.exists(str(data.RecordFolder))): #create record folder
         try:
             os.mkdir(data.RecordFolder)
         except:
@@ -201,6 +201,7 @@ def StopRecordFile():
 def LoadFileList():
     print "Load list of all csv files in folder:", data.RecordFolder
     output = os.popen("cd "+str(data.RecordFolder)+"; ls -C1 *.csv").read() # run ls and make the output look like a file I can read
+    #Note: Above command could also be implemented with os.listdir(). This might give a minor speed improvement
     data.arrRecordFiles=output.split("\n")
     data.arrRecordFiles.pop()
     if(data.debug==True): print data.arrRecordFiles
@@ -227,11 +228,11 @@ def LoadRecord():
 
     data.RecordFolder=string.replace(data.RecordFolder, "~", data.homedir) #workaround
     print "Open recordfile:", data.RecordFolder+data.RecordFilename, "to load data..."
-    if(not os.path.exists(data.RecordFolder)): #create record folder (dirty workaround for if folder is not existing
+    if(not os.path.exists(str(data.RecordFolder))): #create record folder (dirty workaround for if folder is not existing
         os.mkdir(data.RecordFolder)
         data.LastRecord=""
     f=data.RecordFolder+data.RecordFilename
-    if(not os.path.exists(f) or data.RecordFilename==""): return 2 #selected file or folder does not exist
+    if(not os.path.exists(str(f)) or data.RecordFilename==""): return 2 #selected file or folder does not exist
 
     file = open(f, 'r')
 
