@@ -425,9 +425,9 @@ def SwitchModes(start):
             else: #end of recording
                 if(data.SwitchedModes==True): #protection so it only gets switched once
                     data.SwitchedModes=False
-                    if(data.OfflineMode==True and data.demo!=1): #change to online mode
+                    if(data.OfflineMode==True): #change to online mode
                        set_profile(True)
-                    if(data.SilentProfile==True and data.demo!=1): #change to general profile
+                    if(data.SilentProfile==True): #change to general profile
                         set_silent(False)
                     SetVolume(data.PreviousVolume)
 
